<!-- ============================================================= -->
<!--                    HEADER                                     -->
<!-- ============================================================= -->
<!--  MODULE:    SiberSafe CMS Domain                              -->
<!--  VERSION:   1.2                                               -->
<!--  DATE:      October, 2007                                     -->
<!--                                                               -->
<!-- ============================================================= -->

<!-- ============================================================= -->
<!--                    PUBLIC DOCUMENT TYPE DEFINITION            -->
<!--                    TYPICAL INVOCATION                         -->
<!--                                                               -->
<!--  Refer to this file by the following public identifier or an 
      appropriate system identifier 
PUBLIC "-//SIBERLOGIC//DITA SiberSafe Specialization//EN"
      Delivered as file "sibersafe.mod"                            -->

<!-- ============================================================= -->
<!-- SYSTEM:     Darwin Information Typing Architecture (DITA)     -->
<!--                                                               -->
<!-- PURPOSE:    Addition of elements and attributes used by the   -->
<!--             SiberSafe CMS to handle special processing        -->
<!--                                                               -->
<!-- ORIGINAL CREATION DATE:                                       -->
<!--             August 2006                                       -->
<!--                                                               -->
<!--             (C) Copyright SiberLogic, Inc 2006.               -->
<!--             All Rights Reserved.                              -->
<!--                                                               -->
<!--  UPDATES:   v 1.1 Added specialization for text-entity in SS  -->
<!--             that is used to hold text entity info so that     -->
<!--                                                               -->
<!--             v 1.2 Changed specialization for text-entity and  -->
<!--             annotation-end. Now specialized off of keyword    -->
<!--             allowing for more flexible usage of the element.  -->
<!--             Also removed conref and otherprops attributes.    -->
<!--             Added SiberSafe SCM elements and glossary-term.   -->
<!--                                                               -->
<!--  ATTENTION: Annotation element attributes are out of spec     -->
<!--             and must be changed to compatible attributes      -->
<!--             once SiberSafe Annotation and Review consoles     -->
<!--             have been redesigned to work with the appropriate -->
<!--             attributes.                                       -->
<!--                                                               -->
<!--             These changes are to include:                     -->
<!--             attribute "user" is replaced by "author" for the  -->
<!--                        annotation-text element and removed    -->
<!--                        from the annotation element            -->
<!--             attribute "time" is moved from the annotation     -->
<!--                        element to the annotation-text element -->
<!--             attribute "accepted" is replaced by "disposition" -->
<!--                        and the choices replaced with accepted -->
<!--                        or rejected on editor-comment          -->
<!--             attribute "startid" is replaced by "keyref" for   -->
<!--                        the annotation-end element             -->
<!--                                                               -->
<!-- ============================================================= -->

<!-- ============================================================= -->
<!--                   ELEMENT NAME ENTITIES                       -->
<!-- ============================================================= -->

<!ENTITY % annotation  "annotation"                                  >
<!ENTITY % annotation-text
                       "annotation-text"                             >
<!ENTITY % annotation-end
                       "annotation-end"                              >     
<!ENTITY % editor-comment
                       "editor-comment"                              >
<!ENTITY % text-entity
                       "text-entity"                                 >
                       
<!ENTITY % glossary-term
                       "glossary-term"                               >

<!ENTITY % semantic-term
                       "semantic-term"                               >

<!ENTITY % fact        "fact"                                        >

<!ENTITY % fact-object "fact-object"                                 >

<!ENTITY % fact-subject
                       "fact-subject"                                >

<!ENTITY % fact-predicate
                       "fact-predicate"                              >

<!-- ============================================================= -->
<!--                    ELEMENT DECLARATIONS                       -->
<!-- ============================================================= -->


<!--                    LONG NAME: Annotation Container            -->
<!ELEMENT annotation    (%annotation-text;, (%editor-comment;)*)     >
<!ATTLIST annotation              
             id         ID                               #IMPLIED
             conref     CDATA                            #IMPLIED
             otherprops (write | read)                   #IMPLIED
             %outputclass-att;                                       >

<!--                    LONG NAME: Annotation Text                 -->
<!ELEMENT annotation-text
                        (#PCDATA)                                    >
<!ATTLIST annotation-text              
             conref     CDATA                            #IMPLIED
             otherprops (write | read)                   #IMPLIED
             author     CDATA                            #IMPLIED
             time       CDATA                            #IMPLIED
             %outputclass-att;                                       >


<!--                    LONG NAME: Editor Comments                 -->
<!ELEMENT editor-comment
                        (#PCDATA)                                    >
<!ATTLIST editor-comment             
             id         ID                               #IMPLIED
             conref     CDATA                            #IMPLIED
             otherprops (write | read)                   #IMPLIED
             author     CDATA                            #IMPLIED
             time       CDATA                            #IMPLIED
             disposition 
                        (accepted|rejected)              #IMPLIED
             %outputclass-att;                                       >


<!--                    LONG NAME: Annotation End Marker           -->
<!ELEMENT annotation-end
                        EMPTY                                        >
<!ATTLIST annotation-end            
             id         ID                               #IMPLIED
             conref     CDATA                            #IMPLIED
             otherprops (write | read)                   #IMPLIED
             keyref     NMTOKEN                          #REQUIRED
             %outputclass-att;                                       >

<!--                    LONG NAME: Text Entity Placeholder         -->
<!ELEMENT text-entity   (#PCDATA)                                    >
<!ATTLIST text-entity
             id         ID                               #IMPLIED
             keyref     NMTOKEN                          #REQUIRED    
             %outputclass-att;                                       >

<!--                    LONG NAME: Glossary Term Link              -->
<!ELEMENT glossary-term (%xrefph.cnt;)*                              >
<!ATTLIST glossary-term
             id         ID                               #IMPLIED
             href       CDATA                            #REQUIRED
             type       (glossary)                       "glossary"
             %outputclass-att;                                       >

<!--                    LONG NAME: Semantic Term Link              -->
<!ELEMENT semantic-term (%xrefph.cnt;)*                              >
<!ATTLIST semantic-term
             id         ID                               #IMPLIED
             href       CDATA                            #REQUIRED
             type       (semantic)                       "semantic"
             %outputclass-att;                                       >

<!--                    LONG NAME: Semantic Fact Container         -->
<!ELEMENT fact          (%fact-object;, %fact-subject;,
                         %fact-predicate;)                           >
<!ATTLIST fact
             id         ID                               #IMPLIED    >

<!--                    LONG NAME: Semantic Fact Object            -->
<!ELEMENT fact-object   EMPTY                                        >
<!ATTLIST fact-object
             id         ID                               #IMPLIED
             keyref     NMTOKEN                          #REQUIRED   >

<!--                    LONG NAME: Semantic Fact Subject           -->
<!ELEMENT fact-subject  EMPTY                                        >
<!ATTLIST fact-subject
             id         ID                               #IMPLIED
             keyref     NMTOKEN                          #REQUIRED   >

<!--                    LONG NAME: Semantic Fact Predicate         -->
<!ELEMENT fact-predicate
                        EMPTY                                        >
<!ATTLIST fact-predicate
             id         ID                               #IMPLIED
             keyref     NMTOKEN                          #REQUIRED   >


<!-- ============================================================= -->
<!--                    SPECIALIZATION ATTRIBUTE DECLARATIONS      -->
<!-- ============================================================= -->


<!ATTLIST annotation  %global-atts;  class CDATA
                                       "+ topic/ph sl-d/annotation " >
<!ATTLIST annotation-end
                      %global-atts;  class CDATA
                              "+ topic/keyword sl-d/annotation-end " >
<!ATTLIST annotation-text
                      %global-atts;  class CDATA
                       "+ topic/draft-comment sl-d/annotation-text " >
<!ATTLIST editor-comment
                      %global-atts;  class CDATA
                         "+ topic/draft-comment sl-d/editor-comment ">
<!ATTLIST text-entity
                      %global-atts;  class CDATA
                                  "+ topic/keyword sl-d/text-entity ">

<!ATTLIST glossary-term
                      %global-atts;  class CDATA
                                  "+ topic/xref sl-d/glossary-term " >

<!ATTLIST semantic-term
                      %global-atts;  class CDATA
                                  "+ topic/xref sl-d/semantic-term " >

<!ATTLIST fact
                      %global-atts;  class CDATA
                                  "+ topic/ph sl-d/fact "            >

<!ATTLIST fact-object
                      %global-atts;  class CDATA
                                  "+ topic/cite sl-d/fact-object "   >

<!ATTLIST fact-subject
                      %global-atts;  class CDATA
                                  "+ topic/cite sl-d/fact-subject "  >

<!ATTLIST fact-predicate
                      %global-atts;  class CDATA
                                  "+ topic/cite sl-d/fact-predicate" >

<!-- ================== DITA SiberSafe CMS Domain ================ -->